const backImage = chrome.runtime.getURL('base_back.png');
const forwardImage = chrome.runtime.getURL('base_forward.png');
const shadowImage = chrome.runtime.getURL('base_shadow.png');
const moveAreaTopLeft = {x:70, y:75};
const eyeCenter = {x:77, y:79};

let touch = '';
let defaultPosition;

function moveImage(event) {
    const forward = document.getElementById('eye-one-forward');
    const shadow = document.getElementById('eye-one-shadow');
    const point = {x: window.innerWidth - event.clientX, y: window.innerHeight - event.clientY};

    // マウスカーソルが領域外
    if (!(point.x < forward.width && point.y < forward.height)) {
        forward.style.bottom = 0;
        forward.style.right = 0;
        shadow.style.bottom = 0;
        shadow.style.right = 0;
        return
    }

    // 既に下に避けてる状態
    if (parseInt(forward.style.bottom) < 0) {
        forward.style.bottom = -(forward.height - point.y) + "px";
        forward.style.right = 0;
        shadow.style.bottom = -(forward.height - point.y) + "px";
        shadow.style.right = 0;
        return
    }

    // 既に右に避けてる状態
    if (parseInt(forward.style.right) < 0) {
        forward.style.bottom = 0;
        forward.style.right = -(forward.width - point.x) + "px";
        shadow.style.bottom = 0;
        shadow.style.right = -(forward.width - point.x) +"px";
        return
    }

    // 左から触れようとした
    if (point.x > point.y) {
        forward.style.bottom = 0;
        forward.style.right = -(forward.width - point.x) + "px";
        shadow.style.bottom = 0;
        shadow.style.right = -(forward.width - point.x) + "px";
        return
    }

    // 上から触れようとした
    forward.style.bottom = -(forward.height - point.y) +"px";
    forward.style.right = 0;
    shadow.style.bottom = -(forward.height - point.y) + "px";
    shadow.style.right = 0;
    return
}

function setEyePosition(event) {
    const forward = document.getElementById('eye-one-forward');
    const back = document.getElementById('eye-one-back');

    const basePoint = {
        x: window.innerWidth - eyeCenter.x - parseInt(forward.style.right), 
        y: window.innerHeight - eyeCenter.y - parseInt(forward.style.bottom)
    };
    const distance = {x: basePoint.x - event.clientX, y: basePoint.y - event.clientY };
    const ratio = {
        x: (eyeCenter.x - moveAreaTopLeft.x) / basePoint.x,
        y: (eyeCenter.y - moveAreaTopLeft.y) / basePoint.y
    };
    back.style.right = distance.x * ratio.x + parseInt(forward.style.right) + "px";
    back.style.bottom = distance.y * ratio.y + parseInt(forward.style.bottom) + "px";
}

function imageInsert() {
    const forward = document.createElement('img');
    forward.src = forwardImage;
    forward.style.position = 'fixed';
    forward.style.bottom = 0;
    forward.style.right = 0;
    forward.id = 'eye-one-forward';

    const back = document.createElement('img');
    back.src = backImage;
    back.style.position = 'fixed';
    back.style.bottom = 0;
    back.style.right = 0;
    back.id = 'eye-one-back';

    const shadow = document.createElement('img');
    shadow.src = shadowImage;
    shadow.style.position = 'fixed';
    shadow.style.bottom = 0;
    shadow.style.right = 0;
    shadow.style.opacity = 0.7;
    shadow.style.mixBlendMode = 'overlay';
    shadow.id = 'eye-one-shadow';

    const body = document.getElementsByTagName('body')[0]
    body.appendChild(back);
    body.appendChild(shadow);
    body.appendChild(forward);

    const pos = forward.getBoundingClientRect();
    defaultPosition = {x: pos.left, y: pos.top};
}
imageInsert();
document.body.addEventListener('mousemove', function(e){
    moveImage(e);
    setEyePosition(e);
});
